import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * In this version, the Counter is in charge of its own Incrementer, which
 * is an instance of an inner class.
 * An advantage is that it no longer needs to provide a public increment() method
 * so the ONLY object that can increment a Counter is its own Incrementer.
 * In addition, the Incrementer no longer needs to be explicitly told what
 * Counter it belongs to, as an instance of a (non-static) inner class is
 * automatically tied to an instance of its containing class.
 * 
 * @version 4, Feb 2
 */
public class Counter
{
    private int current = 0;
    private CounterIncrementer incr;
    
    public Counter ()
    {
        this.incr = new CounterIncrementer();
    }

    /**
     * get an ActionListener that will increment this Counter.
     * @since version 4
     * @return an ActionListener
     */
    public ActionListener getIncrementer ()
    {
        return this.incr;
    }
    

    /**
     * An ActionListener that responds to timer events by incrementing a Counter
     * and printing the new value.
     * @version 4, Feb 2
     * @since version 2
     */
    class CounterIncrementer implements ActionListener
    {
        /**
         * Respond to a timer event by incrementing and displaying the counter.
         * 
         * @since version 2
         */
        public void actionPerformed (ActionEvent e)
        {
            Counter.this.current++;
            System.out.println ("Counter is " + Counter.this.current);
        }
    }
}
