import javax.swing.JOptionPane;
import javax.swing.Timer;
import java.util.Observer;
import java.util.Observable;

/**
 * Create two Counters with associated Timers, and a "quit" dialog box so we can
 * end the program a little more neatly.
 * In this version, Testbed no longer knows what it takes to increment a Counter;
 * it is assumed that each Counter will provide an incrementer for itself.  In
 * addition, we move a little closer to a "model/view" framework by providing a
 * separate object to display the results of the modified Counter.  This is done
 * using the Observable/Observer approach: each Counter has one or more Observers
 * which will be informed whenever it changes so they can display its new value.
 * Both Observers are instances of anonymous inner classes.
 * @since version 3, Feb 2
 * @version 6, Feb 2
 */
public class Testbed
{
    public static void test ()
    {
        Counter a = new Counter ();
        Counter b = new Counter ();
        a.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter a value: " + newValue);
            }
        });
        b.addObserver (new Observer () {
            public void update (Observable o, Object newValue) {
                System.out.println ("Counter b value: " + newValue);
            }
        });
        Timer timerA = new Timer(1000, a.getIncrementer());
        Timer timerB = new Timer(2000, b.getIncrementer());
        timerB.start();
        timerA.start();
        JOptionPane.showMessageDialog(null, "Quit?");
        System.exit(0);
    }
}
